Opinions & Announcements Search
Description: Opinion Site
Keywords: Decisions, Opinions, Files, Documents, Reporter

# The Supreme Court of Ohio & The Ohio Judicial System

## Opinions & Announcements
Source: |
Decided: |
WebCite No: |
Full Text: |
Enter either a webcite number or a full text query.
Columns to Include
Case Name Case No Topics/Issues | Author County Citation | Decided Date Posted Date WebCite
Notices
Supreme Court opinions and Supreme Court announcements are usually posted weekdays at 9:00 a.m. Other documents are posted as received by the court.
All documents are in the Adobe® PDF format. The Adobe® Reader® is a free download. |
| Rows per Page

118 documents were found matching the selected criteria.
Page: [ 1] 2 next

Case Name | Case No. | Topics and Issues | Author | Decided | WebCite
--- | --- | --- | --- | --- | ---
State v. Burkes | 13CA3582 | CRIMINAL- Postsentence motion to withdraw guilty plea; Petition for postconviction relief; Crim.R. 32.1; R.C. 2953.21; R.C. 2953.23; Manifest injustice; Recasting motions | Hoover | 7/29/2014 | 2014-Ohio-3311
In re B.E. | 13CA26 | Permanent custody proceedings; dependent child; R.C. 2151.281(C); Juv.R. 4(B)(3); R.C. 2151.414(B)(1). | Hoover | 7/14/2014 | 2014-Ohio-3178
Cochenour v. Cochenour | 13CA3420 | Divorce decree; void judgment; voidable judgment; estoppel; motion to vacate void judgment; consent judgment | Hoover | 7/14/2014 | 2014-Ohio-3128
State v. Hess | 13CA15 | The trial court’s failure to instruct the jury that defendant had entered a not guilty by reason of insanity plea was not structural or plain error where the defendant did not advance a defense of legal insanity at trial. | Hoover | 7/14/2014 | 2014-Ohio-3193
State v. Bradshaw | 14CA8 | jail-time credit, res judicata | Harsha | 7/14/2014 | 2014-Ohio-3148
State v. Waters | 13CA693 | CRIMINAL - Appellant's conviction for OVI was not in error as no ineffective assistance of counsel took place and prosecutor's conduct was not plain error. | McFarland | 7/10/2014 | 2014-Ohio-3109
In re J.H. | 14CA4 | JUVENILE - Award of permanent custody of child to Appellee was in best interest of child and not against the manifest weight of the evidence. | McFarland | 7/10/2014 | 2014-Ohio-3108
State v. Jenkins | 13CA3413 | Ineffective assistance of counsel–trial counsel did not render ineffective assistance of counsel by failing to challenge allegedly biased juror when juror indicated she could be impartial and when appellant could not show a reasonable probability that the result of the trial would have been different if trial counsel had excused the juror; trial counsel did not render ineffective assistance of counsel by inviting testimony that appellant may have been under the influence of substance other than alcohol when appellant could not establish prejudice resulting from testimony; Manifest weight of the evidence–appellant’s operating a motor vehicle while under the influence of alcohol conviction was not against the manifest weight of the evidence. | Abele | 7/10/2014 | 2014-Ohio-3123
State v. Graham | 13CA11 | Howard charge Jury instructions Plain error Contempt Felony sentencing | Chris | 7/10/2014 | 2014-Ohio-3149
Wells Fargo Bank, N.A. v. Dumm | 13CA5 | Civil & Appellate Procedure: Case was final appealable order for purposes of R.C. 2505.02 and Civ.R. 54(C) despite court’s failure to expressly resolve all claims; trial court correctly entered judgment for party-defendant under Civ.R. 12(B)(6); trial court erred in entering summary judgment for counterclaims outside the scope of opposing party’s motion for summary judgment; trial court correctly entered summary judgment on claims that were within the scope of movant’s motion. | Per Curiam | 7/9/2014 | 2014-Ohio-3124
State v. Frazier | 13CA5 | aggravated arson; R.C. 2909.02(A)(1); R.C. 2909.02(A)(2); allied offenses of similar import; single animus; same conduct; merger; concurrent sentence | Harsha | 6/30/2014 | 2014-Ohio-3025
State v. Moore | 13CA965 | plea bargain, consideration, ineffective assistance, allied offenses, postrelease control, special felonies | Harsha | 6/30/2014 | 2014-Ohio-3024
Patel v. Lambrecht | 13CA3 | Proof of service; certificate of service; Civ.R. 5 | Hoover | 6/26/2014 | 2014-Ohio-2953
State v. Johnson | 13CA988 | Criminal Procedure: Appellant was barred by the doctrine of res judicata from arguing additional jail time should have been credited to his prison sentence; Appellant did not establish the trial court erred in determining he was not entitled to reduction on his sentence for time spend in jail prior to conviction and sentence. | Abele | 6/26/2014 | 2014-Ohio-3027
State v. Zanni | 13CA3392 | OVI; R.C. 4511.19(D)(1)(b); Intoxilyzer; breath test reliability; admissibility of breath test results | Per Curiam | 6/24/2014 | 2014-Ohio-2806
State v. Andrews | 13CA22 | Resisting arrest; R.C. 2921.33(A); sufficiency of the evidence; allied offenses; merger; R.C. 2941.25; double jeopardy; “same elements” test | Hoover | 6/24/2014 | 2014-Ohio-2954
In re S.M. | 14CA4 | Permanent custody—trial court need only find existence of one R.C. 2151.414(B) factor; best interests—trial court erred by failing to consider the child’s wishes, one of the enumerated R.C. 2151.414(D) best interest factors, but error did not constitute plain error requiring reversal | Harsha | 6/18/2014 | 2014-Ohio-2961
State v. Lamb | 14CA3 | Res Judicata, Improper Argument, Plain Error, Failure to order transcript | Harsha | 6/18/2014 | 2014-Ohio-2960
State v. Batty | 13CA3398 | CRIMINAL - This Court has no jurisdiction to address merits of Appellant's recusal argument and sentence imposed is not clearly and convincingly contrary to law. | McFarland | 6/18/2014 | 2014-Ohio-2826
State v. Burton | 13CA12 | CRIMINAL- Petition for postconviction relief; R.C. 2953.23; Ineffective assistance of counsel during plea negotiations; Res judicata | Hoover | 6/10/2014 | 2014-Ohio-2549
Miller Fireworks Co., Inc. v. Jackson | 13CA30 | Denial of motion for relief from default judgment was proper where service of lawsuit was perfected upon appellant and appellant waited seven and a half years to seek relief. | Hoover | 6/5/2014 | 2014-Ohio-2545
State v. Hall | 13CA3391 | aggravated murder; possession of a deadly weapon while under detention; manifest weight; self-defense; impeachment; prior inconsistent statement; Evid.R. 613(B); foundation; denial; plain error; failure to object; limiting instruction; failed to request; Evid.R. 105; prosecutorial misconduct; closing argument; substantive evidence; duress; outside force; ineffective assistance of counsel; prejudice | Harsha | 6/4/2014 | 2014-Ohio-2959
State v. Kessigner | 13CA25 | CRIMINAL- Crim.R.29(A) motion for acquittal; Assault on a Peace Officer; Jury instructions; Ineffective assistance of counsel; Evid.R. 803(5); Evid.R. 609(A)(2); Counsel's motion to withdraw | Hoover | 6/3/2014 | 2014-Ohio-2496
State v. Gambrel | 13CA17 | Juvenile Law: Pursuant to Anders v. California (1967), 386 U.S. 738, 87 S.Ct. 1396, 18 L.Ed.2d 493, there are no meritorious issues for appeal. | Abele | 6/2/2014 | 2014-Ohio-2520
State v. Sanders | 13CA29 | Criminal Sentencing: Trial court correctly ruled issues raised in a motion to “correct unlawful sentence” were barred from being raised by the doctrine of res judicata and the motion itself was an untimely petition for postconviction relief. | Abele | 5/30/2014 | 2014-Ohio-2521
Gilbrath v. Autozone, Inc. | 13CA1 | Workers’ Compensation–commission’s decision did not involve claimant’s right to participate when decision denied compensation for a period of time and explicitly stated that claimant could seek future benefits, even though district hearing officer found that intervening injury broke chain of causation. | Abele | 5/27/2014 | 2014-Ohio-2347
State v. Crum | 13CA13 | CRIMINAL - Appellant's motion for "Re-sentencing" construed as a petition for post-conviction relief was untimely filed and we and the trial court lacked jurisdiction to hear the same. | McFarland | 5/27/2014 | 2014-Ohio-2361
State v. Felts | 13CA3407 | Validity of no contest plea, Appealability of in limine ruling, Knowing and voluntary plea | Harsha | 5/23/2014 | 2014-Ohio-2378
Boone Coleman Constr., Inc. v. Village of Piketon | 13CA836 | Summary judgment, Construction, contract, Liquidated damages, Penalty provision, Notice provisions, Subsurface claims, unenforceable penalty | Harsha | 5/22/2014 | 2014-Ohio-2377
State v. Ogle | 13CA18 | CRIMINAL - Trial court did not err in denying Appellant's motion to withdraw her Alford plea, to set aside her sentence and to dismiss her indictment. | McFarland | 5/21/2014 | 2014-Ohio-2251
State v. Eldridge | 13CA3584 | CRIMINAL - Because Appellant's petition for post-conviction relief was untimely, we and the trial court lacked jurisdiction to hear the same. | McFarland | 5/21/2014 | 2014-Ohio-2250
Bolender v. Bolender | 13CA984 | Divorce; modification of temporary spousal support award; R.C. 3105.18(E); permanent spousal support award; R.C. 3105.18(C)(1). | Hoover | 5/15/2014 | 2014-Ohio-2136
State v. Houston | 12CA3472 | CRIMINAL - Trial court substantially complied with Crim.R.11(C)(2) in advising Appellant as to maximum penalties and his plea was made knowingly, voluntarily, and intelligently. | McFarland | 5/14/2014 | 2014-Ohio-2827
State v. McCallister | 13CA3558 | Statutory speedy trial rights; joint constructive possession of contraband located in vehicle. | Hoover | 5/12/2014 | 2014-Ohio-2041
State v. Greer | 13CA2 | allied offenses of similar import, double jeopardy, illegal manufacture of drugs, endangering children | Harsha | 5/9/2014 | 2014-Ohio-2174
State v. Steinhauer | 12CA3528 | CRIMINAL- Self defense jury instruction; Character evidence; Evid.R. 405; Evid.R. 404; Specific instances of conduct; Defendant's state of mind | Hoover | 5/8/2014 | 2014-Ohio-1981
State v. Chaffins | 13CA3559 | Automobile exception to warrantless search of vehicle; joint constructive possession of contraband located in vehicle. | Hoover | 5/7/2014 | 2014-Ohio-1969
State v. Weddington | 13CA3560 | right to counsel; self-representation; Sixth Amendment; waiver; knowing, intelligent and voluntary; totality of the circumstances; de novo; Crim.R. 44; literal compliance; written waiver; substantial compliance; sufficient inquiry; nature of the charges; statutory offenses; possible punishment; substitute counsel; showing of good cause | Harsha | 5/6/2014 | 2014-Ohio-1968
Am. Savs. Bank v. Wrage | 13CA3566 | Appellate court conducts de novo review of summary judgment; affidavit testimony authenticate promissory note attached to complaint. | Abele | 5/5/2014 | 2014-Ohio-2168
Dolan v. Glouster | 11CA18, 11CA19, 11CA33, 12CA1, 12CA6 | Civil Procedure/Tort/Appellate Procedure: Trial court’s judgment was a final order despite failure to resolve claims against “John Doe” defendants where no service was ever obtained defendants; court did not err in denying Civ.R. 50 judgment notwithstanding the verdict (JNOV) on claims of tortious interference with a business relationship; JNOV is reviewed de novo and not for an abuse of discretion; a business relationship, for purposes of the tort of interfering with business relationship, requires some sort of a pecuniary expectation; judgment in a civil case can be based on circumstantial evidence; if evidence introduced a trial is inaccurate or misleading that goes to the weight afforded the evidence and not its admissibility; trial court did not err in granting leave of court to file a third amended complaint; leave of court is to be freely granted pursuant to Civ.R. 15 as well as the policy that claims should be decided on their merits rather on the basis of pleading technicalities; interlocutory orders, such as a dismissal of party defendants can be reconsidered, and reversed, at any time before entry of final judgment; appellate courts should refrain from issuing advisory opinions; once appeal is perfected, trial court has no jurisdiction over matters that are inconsistent with an appellate court’s ability to reverse, affirm or modify a judgment; punitive damages are conceptually different than compensatory damages; trial court did not abuse its discretion in granting a motion for new trial pursuant to Civ.R. 59(A)(4) regarding damages awarded for emotional distress and for punitive damages; trial court did not err in granting JNOV for defendant charged with tortiously interfering with a business relationship when no evidence was introduced at trial to show defendant had any control over county employees who stopped using said business; trial court did not abuse its discretion in determining the amount of attorney fees to award successful parties; trial court did not abuse its discretion in denying motion for pre-judgment interest pursuant to R.C. 1343.03(C). | Per Curiam | 5/5/2014 | 2014-Ohio-2017
Burns v. Adams | 12CA3508 | CIVIL - Trial court did not err in evidentiary rulings and did not deprive Appellant of a fair trial. And, punitive damage award was not excessive or contrary to law. | McFarland | 5/2/2014 | 2014-Ohio-1917
State v. West | 12CA3507 | Criminal law: Verdicts on charge of trafficking were not against the manifest weight of the evidence; failure of counsel to ask for an instruction under R.C. 2923.03 was not plain error; the appellant did not suffer ineffective assistance of trial counsel for failure to request a jury instruction under R.C. 2923.03; weight and credibility of witness testimony is an issue for the trier of fact and the jury’s rejection of appellant’s version of events, and acceptance of that given by the State’s witnesses, was not against the manifest weight of the evidence. | Abele | 5/1/2014 | 2014-Ohio-1941
In re C.R. | 13CA3411 | Juvenile delinquency–juvenile offender registrant–trial court did not fail to exercise discretion when classifying juvenile as Tier III offender; trial court did not err by imposing sanction that extends beyond its age jurisdiction. | Abele | 4/30/2014 | 2014-Ohio-1936
Detty v. Yates | 13CA3390 | Void judgment–trial court’s judgment was not void for lack of personal jurisdiction when plaintiffs complied with Civil Rules regarding service of process, even though defendant claimed he did not receive actual service; voidable judgment–defendant entitled to hearing on Civ.R. 60(B)(1) motion for relief from judgment when defendant presents operative facts showing that defendant has meritorious defense to present, that failure to answer complaint resulted from excusable neglect, and that motion filed within a reasonable time; failure to answer complaint due to lack of actual notice of complaint may constitute excusable neglect. | Abele | 4/30/2014 | 2014-Ohio-1935
State v. Baker | 13CA18 | withdrawal of court-appointed counsel disproportionate sentences ineffective assistance of counsel consecutive sentences | Harsha | 4/30/2014 | 2014-Ohio-1967
Deutsche Bank Natl. Trust Co. v. Edington | 13CA3534 | final appealable order, foreclosure, dismissal without prejudice | Harsha | 4/24/2014 | 2014-Ohio-1769
State v. Brewer | 14CA1 | Ineffective assistance of counsel, Standard of review-felony sentencing, Restitution, Ability to pay | Harsha | 4/24/2014 | 2014-Ohio-1903
Hardert v. Neumann | 13CA977 | adverse possession; open and notorious; lawn maintenance; mowing grass; growing hay; federal Conservation Reserve Program; totality of the circumstances; manifest weight; competent, credible evidence. | Harsha | 4/23/2014 | 2014-Ohio-1770
Donini v. Manor Care, Inc. | 13CA3583 | Jurisdiction, Judgment on the pleadings, employer-initiated workers' compensation appeal, stipulated dismissal | Harsha | 4/21/2014 | 2014-Ohio-1767
State v. Miller | 13CA5 | Criminal Law: Appellant failed to establish trial court erred or abused its discretion imposing maximum, consecutive, sentences on charges to which he pled guilty under a plea agreement. | Abele | 4/21/2014 | 2014-Ohio-1803
Wells Fargo Bank, N.A. v. Smith | 13CA6 | Civil Procedure: Multiple motions for relief from judgment under Civ.R. 60(B) are barred under the doctrine of res judicata where they rely on grounds that were raised, or could have been raised, in prior motions; Civ.R. 60(B) motion for relief from judgment cannot be used as a substitute for an appeal. | Abele | 4/21/2014 | 2014-Ohio-1802
State v. Primack | 13CA23 | concurrent sentences; jail-time credit; R.C. 2967.191; Equal Protection; unrelated offenses | Harsha | 4/17/2014 | 2014-Ohio-1771
State v. Cole | 12CA49 | allied offenses of similar import R.C. 2941.25 | Harsha | 4/17/2014 | 2014-Ohio-2967
In re C.J.L. | 13CA3545 | temporary custody; abuse of discretion; paramount right; unsuitability; R.C. 3109.04(E)(1)(a); change in circumstances; best interests; jurisdiction; neglect; R.C. 2151.23(A)(1); R.C. 2151.03; R.C. 2151.353(F); sunset provision; R.C. 2151. 353(E)(1). | Harsha | 4/14/2014 | 2014-Ohio-1766
State v. James | 13CA3393 | Pro se motion to dismiss–trial court need not consider pro se motion to dismiss when defendant represented by counsel; trial counsel not ineffective for failing to file motion to dismiss on speedy trial grounds when motion would not have been successful. | Abele | 4/11/2014 | 2014-Ohio-1702
State v. Love | 13CA16 | CRIMINAL - Appellant's convictions for multiple felony offenses were supported by sufficient evidence in the record and merger was not required. The sentence imposed was lawful. | McFarland | 4/10/2014 | 2014-Ohio-1603
Sites v. Alcohol, Drug Addiction & Mental Health Servs. | 13CA3547 | Summary judgment; that the court of claims does not have exclusive jurisdiction is not the same issue as whether a political subdivision enjoys the benefit of R.C. Chap. 2744 immunity. | Abele | 4/10/2014 | 2014-Ohio-1819
Faulks v. Flynn | 13CA3568 | shared parenting, plain error, waiver, failure to object to magistrate's decision, independent review | Harsha | 4/9/2014 | 2014-Ohio-1610
In re J.M.D. | 14CA2 | permanent custody, best interest of the child, manifest weight of the evidence, R.C. 2151.414(B)(2) | Harsha | 4/9/2014 | 2014-Ohio-1609
In re C.A. | 13CA24 | JUVENILE - No plain error occurred in the trial court regarding appointment of a guardian ad litem or independent counsel for the child. | McFarland | 4/8/2014 | 2014-Ohio-1550
State v. Gierhart | 13CA17 | Error in jury instruction was not so severe as to mislead the jury or to constitute plain error. A review of the complete instruction demonstrates that the trial court provided the jury with adequate instructions. | Hoover | 3/31/2014 | 2014-Ohio-1419
State v. Stump | 13CA10 | Criminal Law: Trial court did not err sentencing appellant to pay court costs and administrative costs of a diversion program without considering her ability to pay; court erred in ordering appellant to pay restitution to a third party, non-victim, of the crime. | Abele | 3/31/2014 | 2014-Ohio-1487
Prokos v. Hines | 12CA31 | CIVIL - Trial court's decision holding Appellant in contempt of court for holding funds in IOLTA account and that funds were subject to garnishment is supported by competent, credible evidence in the record. | McFarland | 3/28/2014 | 2014-Ohio-1416
Prokos v. Hines | 10CA51, 10CA57 | CIVIL - Trial court's decision in favor of various parties on fraud, conversion, fraudulent conveyance, intentional interferene with expectancy of inheritance claims are supported in the record. | McFarland | 3/28/2014 | 2014-Ohio-1415
Rambacher v. Testa | 13CA14 | taxation, joint estimated tax payments, allocation of tax payments, moot | Harsha | 3/27/2014 | 2014-Ohio-1488
State v. Lister | 13CA15 | CRIMINAL- Felony sentencing review; R.C. 2953.08; Kalish; A sentence contrary to law; Maximum sentence | Hoover | 3/27/2014 | 2014-Ohio-1405
Quality Car & Truck Leasing, Inc. v. Pertuset | 13CA3565 | CIVIL - Because this Court has already affirmed trial court's grant of judgment on pleadings in favor of Appellees, Appellant's arguments are barred by the doctrines of res judicata and law of the case. Judgment affirmed. | McFarland | 3/27/2014 | 2014-Ohio-1291
Am. Savs. Bank v. Pertuset | 13CA3564 | CIVIL - The original grant of summary judgment and decree in foreclosure stands as valid law of the case as once already affirmed by the Court and trial court's subsequent decision vacating those prior orders is reversed. | McFarland | 3/27/2014 | 2014-Ohio-1290
Farm Credit Servs. of Mid-Am. v. Pertuset | 13CA3563 | CIVIL - The original grant of summary judgment and decree in foreclosure stands as valid law of the case as once already affirmed by this Court and trial court's subsequent decision vacating those prior orders is reversed. | McFarland | 3/27/2014 | 2014-Ohio-1289
State v. Hoffman | 13CA13 | Trial court's imposition of maximum prison sentence for felony domestic violence conviction was not contrary to law. | Hoover | 3/21/2014 | 2014-Ohio-1205
State v. Hawkins | 13CA3 | Pursuant to R.C. 2953.08(D)(3), appellate courts lack authority to review a sentence imposed for aggravated murder on an evidentiary basis. The General Assembly has long treated aggravated murder and murder sentencing differently from other felonies. | Hoover | 3/21/2014 | 2014-Ohio-1224
State v. Hastings | 13CA16 | Hearsay testimony–trial court erred as a matter of law when it permitted witness’s out-of-court police interview without analyzing both Evid.R. 804(A) and 804(B) | Abele | 3/20/2014 | 2014-Ohio-1418
State v. Pemberton | 13CA8 | CRIMINAL- Allied offenses; Res Judicata; Untimely petition for postconviction relief; Unauthorized sentence | Hoover | 3/19/2014 | 2014-Ohio-1204
Hamilton v. Ball | 13CA3533 | Trial court properly determined that defendant committed a single violation of the Ohio Consumer Sales Practices Act when he sold a used vehicle with reported unibody damage without disclosing the damage to the consumers. | Hoover | 3/19/2014 | 2014-Ohio-1118
Smiley v. Prison Official, Inc. | 13CA3408 | Final order, Dismissal without prejudice | Harsha | 3/18/2014 | 2014-Ohio-1100
State v. Kelly | 13CA3562 | CRIMINAL - Appeal dismissed as no final appealable order exists and we lack jurisdiction. | McFarland | 3/17/2014 | 2014-Ohio-1020
Ogle v. Kroger Co. | 13CA22 | summary judgment; abuse of discretion; due process; regulation of discovery; notice; non-oral hearing; Civ.R. 56; Civ.R. 56(C); Civ.R. 56(F) motion; opportunity to complete discovery; App.R. 16(A)(7); argue assigned errors separately | Harsha | 3/14/2014 | 2014-Ohio-1099
State v. Cross | 12CA54 | CRIMINAL- Motion to suppress; OVI; Fourth Amendment of the United States Constitution; Warrantless entry; Exigent circumstances; Hot pursuit in misdemeanor cases | Hoover | 3/11/2014 | 2014-Ohio-1046
Bullard v. Alley | 12CA835 | Civil Protection Order–trial court’s decision was not against the manifest weight of the evidence. | Abele | 3/7/2014 | 2014-Ohio-1016
State v. Lofton | 13CA10 | Rules of Criminal Procedure: Issues raised by appellant in an appeal of his fourth post-trial motion to withdraw guilty plea, had already been raised and determined in previous appeals and were thus barred from being raised again by the doctrine of res judicata. | Abele | 3/5/2014 | 2014-Ohio-1021
State v. Sunday | 13CA19 | CRIMINAL - Appellant's conviction for drug offenses was supported by evidence in the record and as such not against the manifest weight of the evidence. | McFarland | 3/5/2014 | 2014-Ohio-900
Mustard v. Owners Ins. Co. | 13CA3362 | automobile accident; satisfaction of judgment; insurance policy; liquor liability clause; nonprofit; in the business of; alcohol; unambiguous; summary judgment; Civ.R. 56(C); Civ.R. 56(E); no genuine issue of material fact; entitled to judgment as a matter of law. | Harsha | 3/5/2014 | 2014-Ohio-865
State v. Johnson | 13CA3381 | Miranda/Right to counsel: Trial court properly overruled defendant’s motion to suppress incriminating statements because the statements were made voluntarily and spontaneously, and were not the result of custodial interrogation. | Hoover | 2/28/2014 | 2014-Ohio-787
State v. Inman | 13CA3374 | Trial court properly ruled that out of court statement of co-defendant was inadmissible at trial of defendant. Trial court also properly ruled that the prosecution’s opening remarks in trial of co-defendant were inadmissible at trial of defendant. | Hoover | 2/28/2014 | 2014-Ohio-786
Keltz v. Enchanted Hills Community Assn. | 12CA16 | Declaratory judgment, planned community, declaration by laws, assessments | Harsha | 2/28/2014 | 2014-Ohio-866
Douglas v. Broughton | 13CA7 | CIVIL- Surface water trespass; Calculation of damages; Manifest weight standard of review; | Hoover | 2/27/2014 | 2014-Ohio-808
State v. Shrewsbury | 13CA3402 | Motion to suppress, Search and seizure, Consensual encounter, Open view, Protective search for weapons | Harsha | 2/26/2014 | 2014-Ohio-716
State v. Harlow | 13CA29 | OVI; no contest plea; motion to suppress; traffic violation; probable cause; reasonable suspicion; stipulation; admission of evidence; waiver; Fourth Amendment; ineffective assistance; trial strategy; prejudice; driving privileges; administrative license suspension; judicial suspension; sentence. | Harsha | 2/26/2014 | 2014-Ohio-864
Martin v. Lambert | 12CA7 | premises liability—landowner did not owe duty to business invitee when landowner permitted son to use the premises as an automobile repair shop and did not occupy or control the automobile repair shop premises; operation of automobile repair shop is not an inherently dangerous use of property | Harsha | 2/25/2014 | 2014-Ohio-715
Hubbard Family Trust v. TNT Land Holdings, L.L.C. | 12CA833 | Trial court properly denied motions for summary judgment, judgment notwithstanding the verdict, and directed verdict, but erred when it failed to award damages for the defendant's liability. | Brown | 2/25/2014 | 2014-Ohio-772
In re P.A.R. | 13CA3550 | Motion to modify custody between parent and nonparent–mother did not establish change in the child’s or custodians’ circumstances so as to warrant changing custody. | Abele | 2/24/2014 | 2014-Ohio-802
Buckmaster v. Buckmaster | 13CA13 | DOMESTIC RELATIONS - Trial court's unwritten policy and unpublished rule of court preventing children of parties in domestic relations cases to testify was in error and in violation of due process, Sup.R.5 and Civ.R.83. | McFarland | 2/24/2014 | 2014-Ohio-793
State v. Guess | 11CA33 | Trial Court erred by not insuring that defendant's waiver of right to counsel was knowing, intelligent, and voluntary. | Per Curiam | 2/24/2014 | 2014-Ohio-771
State v. Keeley | 13CA34 | Criminal Law: Trial court did not err in overruling petition for postconviction relief; claims which could have been, but were not raised in a first appeal of right are barred from consideration under doctrine of res judicata in proceedings under R.C. 2953.21. | Abele | 2/21/2014 | 2014-Ohio-693
In re D.G. | 13CA3382, 13CA3383 | JUVENILE - Trial court's decision finding juvenile competent to stand trial was supported by the record and in not appointing a guardian ad litem was not error. Appellant's claim of ineffective assistance of trial counsel is without merit. | McFarland | 2/19/2014 | 2014-Ohio-650
State v. Bever | 13CA21 | Trial court's failure to state findings required by R.C. 2929.14(C)(4) prior to imposing consecutive sentences requires remand for resentencing. | Hoover | 2/18/2014 | 2014-Ohio-600
Dean v. UPS Legal Dept. | 13CA21 | Interstate shipping; Interstate Commerce Act; Carmack Amendment; preemption; state law claims; common carriers; property loss or damage | Harsha | 2/14/2014 | 2014-Ohio-619
Dunford v. Dunford | 13CA7 | Motion for relief from judgment, Civ.R. 60(B)(5), Fraud on the court, Reasonable time | Harsha | 2/14/2014 | 2014-Ohio-617
State v. Walton | 13CA9 | minor misdemeanor; speeding; possession of marihuana; notice of appeal; App.R. 3(D); App.R. 4(A); timely appeal; Crim.R. 32.1; motion to withdraw plea; post-sentence; manifest injustice; abuse of discretion; voluntary; failure to raise argument with trial court; waiver; effect of plea; petty offense; Crim.R. 11(E); Traf.R. 10(D); Crim.R. 11(B); Traf.R. 10(B); non-constitutional right; substantial compliance; prejudice; video recording; silent record | Harsha | 2/13/2014 | 2014-Ohio-618
In re J.V-M.P. | 13CA37 | The trial court's decision awarding permanent custody of minor child to children services agency was not against the manifest weight of the evidence. | Hoover | 2/10/2014 | 2014-Ohio-486

Page: [ 1] 2 next